@@ -1,14 +1,9 @@
-# -*- encoding: utf-8 -*-
-#
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
-#
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
@@ -18,12 +13,12 @@
 
 import pecan
 
-from tuskar.api.controllers import v1
+from tuskar.api.controllers.v1 import controller
 
 
 class RootController(object):
 
-    v1 = v1.Controller()
+    v1 = controller.Controller()
 
     @pecan.expose('json')
     def index(self):
