@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
@@ -19,6 +17,7 @@ Base classes for storage engines
 """
 
 import abc
+import six
 
 from tuskar.openstack.common.db import api as db_api
 
@@ -31,11 +30,10 @@ def get_instance():
     return IMPL
 
 
+@six.add_metaclass(abc.ABCMeta)
 class Connection(object):
     """Base class for storage system connections."""
 
-    __metaclass__ = abc.ABCMeta
-
     @abc.abstractmethod
     def __init__(self):
         """Constructor."""
